@@ -54,7 +54,7 @@ sub meta_merge {
 }
 
 sub requires {
-    my ( $self, @extra ) = @_;
+    my ( undef, @extra ) = @_;		# Invocant unused
 
     return {
 	'Carp'			=> 0,
