@@ -1,6 +1,6 @@
 package My::Module::Recommend::Any;
 
-use 5.006002;
+use 5.008;
 
 use strict;
 use warnings;
@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.026_01';
+our $VERSION = '0.018';
 
 our @EXPORT_OK = qw{ __any };
 
@@ -176,9 +176,7 @@ modules are needed it returns nothing.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Sudoku-General>,
-L<https://github.com/trwyant/perl-Games-Sudoku-General/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -186,7 +184,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2022 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
